inside

Function inside 

fn inside(input: &Input, x: i64, y: i64) -> bool
Skip the relatively expensive intcode test if the point lies outside the beam’s slopes. The slope check has some false positives but no false negatives.